==> konoha-0.2.2-rc2.tar.gz: konoha-0.2.2-rc2/konoha/deps/win32/system__win32.c <==
/****************************************************************************
 * KONOHA COPYRIGHT, LICENSE NOTICE, AND DISCRIMER
 *
 * Copyright (c) 2005-2008, Kimio Kuramitsu <kimio at ynu.ac.jp>
 *           (c) 2007       Satoshi Kobayashi <gucchi at ubicg.ynu.ac.jp>
 *           (c) 2008-      Konoha Software Foundation
 * All rights reserved.
 *
 * You may choose one of the following two licenses when you use konoha.
 * See www.konohaware.org/license.html for further information.
 *
 * (1) GNU General Public License 2.0      (with    KONOHA_UNDER_GPL2)
 * (2) Konoha Software Foundation License 1.0
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/

/* ************************************************************************ */

#include"commons.h"

#ifdef KNH_USING_WIN32

#include<windows.h>

#ifdef __cplusplus
extern "C" {
#endif

/* ======================================================================== */
/* [ALT_DLOPEN] */

void *ALT_dlopen(const char* path, int mode)
{
	char buff[FILENAME_BUFSIZ];
	knh_format_ospath(buff, sizeof(buff), B((char*)path));
	void *hdr = (void*)LoadLibraryA((LPCTSTR)buff);
	//fprintf(stderr, "dlopen .. '%s' hdr=%p\n", buff, hdr);
	return hdr;
}

/* ------------------------------------------------------------------------ */

void *ALT_dlsym(void* handle, const char* symbol)
{
	//char buff[FILENAME_BUFSIZ];
	//knh_snprintf(buff, sizeof(buff), "_%s@4", symbol);
	void *p = (void*)GetProcAddress((HMODULE)handle, (LPCSTR)symbol);
	//fprintf(stderr, "dlsym .. '%s', hdr=%p, *p=%p\n", buff, handle, p);
	return p;
}

/* ------------------------------------------------------------------------ */

const char *ALT_dlerror()
{
	return "DLLERROR";
}

/* ------------------------------------------------------------------------ */

int ALT_dlclose(void* handle)
{
	return (int)FreeLibrary((HMODULE)handle);
}

/* ------------------------------------------------------------------------ */

#ifdef __cplusplus
}
#endif

#endif/*KONOHA_USING_WIN32*/

==> konoha-0.2.5.tar.gz: konoha-0.2.5/konoha/deps/win32/system__win32.c <==
/****************************************************************************
 * KONOHA COPYRIGHT, LICENSE NOTICE, AND DISCRIMER
 *
 * Copyright (c) 2005-2008, Kimio Kuramitsu <kimio at ynu.ac.jp>
 *           (c) 2007       Satoshi Kobayashi <gucchi at ubicg.ynu.ac.jp>
 *           (c) 2008-      Konoha Software Foundation
 * All rights reserved.
 *
 * You may choose one of the following two licenses when you use konoha.
 * See www.konohaware.org/license.html for further information.
 *
 * (1) GNU General Public License 2.0      (with    KONOHA_UNDER_GPL2)
 * (2) Konoha Software Foundation License 1.0
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/

/* ************************************************************************ */

#include"commons.h"

#ifdef KNH_USING_WIN32

#include<windows.h>

#ifdef __cplusplus
extern "C" {
#endif

/* ======================================================================== */
/* [ALT_DLOPEN] */

void *ALT_dlopen(const char* path, int mode)
{
	char buff[FILENAME_BUFSIZ];
	knh_format_ospath(NULL, buff, sizeof(buff), B((char*)path));
	void *hdr = (void*)LoadLibraryA((LPCTSTR)buff);
	fprintf(stderr, "dlopen .. '%s' hdr=%p\n", buff, hdr);
	return hdr;
}

/* ------------------------------------------------------------------------ */

void *ALT_dlsym(void* handle, const char* symbol)
{
	//char buff[FILENAME_BUFSIZ];
	//knh_snprintf(buff, sizeof(buff), "_%s@4", symbol);
	void *p = (void*)GetProcAddress((HMODULE)handle, (LPCSTR)symbol);
	fprintf(stderr, "dlsym .. '%s', hdr=%p, *p=%p\n", buff, handle, p);
	return p;
}

/* ------------------------------------------------------------------------ */

const char *ALT_dlerror()
{
	return "DLLERROR";
}

/* ------------------------------------------------------------------------ */

int ALT_dlclose(void* handle)
{
	return (int)FreeLibrary((HMODULE)handle);
}

/* ------------------------------------------------------------------------ */

#ifdef __cplusplus
}
#endif

#endif/*KONOHA_USING_WIN32*/
